@@ -94,7 +94,8 @@ class TestCNClient(tests.TestCase):
         self.session.assert_called_once_with(auth=self.auth.return_value)
         self.client.assert_called_once_with(version=self.version,
                                             endpoint_override=self.url,
-                                            session=self.session.return_value)
+                                            session=self.session.return_value,
+                                            global_request_id=mock.ANY)
 
     def test_getattr(self):
         # TODO(n.s.): Will be done as soon as pypi package will be updated
@@ -346,8 +347,8 @@ class ReservationPoolTestCase(tests.TestCase):
         check0 = self.nova.aggregates.add_host
         check0.assert_has_calls([mock.call(self.fake_aggregate.id, 'host1'),
                                  mock.call(self.fake_aggregate.id, 'host2'),
-                                 mock.call('freepool', 'host1'),
-                                 mock.call('freepool', 'host2')])
+                                 mock.call(self.fake_freepool.id, 'host1'),
+                                 mock.call(self.fake_freepool.id, 'host2')])
         check1 = self.nova.aggregates.remove_host
         check1.assert_has_calls([mock.call(self.fake_freepool.id, 'host1'),
                                  mock.call(self.fake_freepool.id, 'host2'),
@@ -447,7 +448,7 @@ class FakeNovaHypervisors(object):
     class FakeHost(object):
         id = 1
         availability_zone = 'fake_az1'
-        hypervisor_hostname = 'fake_name'
+        hypervisor_hostname = 'fake_name.openstack.org'
         vcpus = 1
         cpu_info = 'fake_cpu'
         hypervisor_type = 'fake_type'
